# PhaseResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**automatic_deployment_targets** | **list[str]** |  | [optional] 
**optional_deployment_targets** | **list[str]** |  | [optional] 
**minimum_environments_before_promotion** | **int** |  | [optional] 
**is_optional_phase** | **bool** |  | [optional] 
**release_retention_policy** | [**RetentionPeriod**](RetentionPeriod.md) |  | [optional] 
**tentacle_retention_policy** | [**RetentionPeriod**](RetentionPeriod.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


